# -*-coding:utf-8 -*-
from sqlalchemy import Column, String, Date, Text, Float, TIMESTAMP
from sqlalchemy.ext.declarative import declarative_base

# 创建对象的基类
Base = declarative_base()


class CN_JQ_SUMMARY(Base):
    # 表的名字
    __tablename__ = 'cn_jq_summary'

    # 表的结构
    date = Column(Date, primary_key=True)
    code = Column(Text, primary_key=True)
    industry_name = Column(Text)
    capitalization = Column(Float(8))
    circulating_cap = Column(Float(8))
    eps_ttm = Column(Float(8))
    sz50 = Column(Float(8))
    hs300 = Column(Float(8))
    zz500 = Column(Float(8))
    zz1000 = Column(Float(8))
    kc50 = Column(Float(8))
    szcz = Column(Float(8))
    cybz = Column(Float(8))
    szzs = Column(Float(8))
    update_time = Column(TIMESTAMP)

    def to_dict(self):
        return {c.name: getattr(self, c.name, None) for c in self.__table__.columns}

    @property
    def columns(self):
        return [c.name for c in self.__table__.columns]

    def to_list(self):
        return [getattr(self, c.name, None) for c in self.__table__.columns]


class CN_JQ_STK_INCOME_STATEMENT_PARENT(Base):
    # 表的名字
    __tablename__ = 'cn_jq_stk_income_statement_parent'

    # 表的结构
    company_id = Column(Float(8))
    company_name = Column(Text)
    code = Column(Text, primary_key=True)
    a_code = Column(Text)
    b_code = Column(Text)
    h_code = Column(Text)
    pub_date = Column(Date)
    start_date = Column(Date)
    end_date = Column(Date)
    report_date = Column(Date)
    report_type = Column(Float(8))
    source_id = Column(Float(8))
    source = Column(Text)
    total_operating_revenue = Column(Float(8))
    operating_revenue = Column(Float(8))
    total_operating_cost = Column(Float(8))
    operating_cost = Column(Float(8))
    operating_tax_surcharges = Column(Float(8))
    sale_expense = Column(Float(8))
    administration_expense = Column(Float(8))
    exploration_expense = Column(Float(8))
    financial_expense = Column(Float(8))
    asset_impairment_loss = Column(Float(8))
    fair_value_variable_income = Column(Float(8))
    investment_income = Column(Float(8))
    invest_income_associates = Column(Float(8))
    exchange_income = Column(Float(8))
    other_items_influenced_income = Column(Float(8))
    operating_profit = Column(Float(8))
    subsidy_income = Column(Float(8))
    non_operating_revenue = Column(Float(8))
    non_operating_expense = Column(Float(8))
    disposal_loss_non_current_liability = Column(Float(8))
    other_items_influenced_profit = Column(Float(8))
    total_profit = Column(Float(8))
    income_tax = Column(Float(8))
    other_items_influenced_net_profit = Column(Float(8))
    net_profit = Column(Float(8))
    np_parent_company_owners = Column(Float(8))
    minority_profit = Column(Float(8))
    eps = Column(Float(8))
    basic_eps = Column(Float(8))
    diluted_eps = Column(Float(8))
    other_composite_income = Column(Float(8))
    total_composite_income = Column(Float(8))
    ci_parent_company_owners = Column(Float(8))
    ci_minority_owners = Column(Float(8))
    interest_income = Column(Float(8))
    premiums_earned = Column(Float(8))
    commission_income = Column(Float(8))
    interest_expense = Column(Float(8))
    commission_expense = Column(Float(8))
    refunded_premiums = Column(Float(8))
    net_pay_insurance_claims = Column(Float(8))
    withdraw_insurance_contract_reserve = Column(Float(8))
    policy_dividend_payout = Column(Float(8))
    reinsurance_cost = Column(Float(8))
    non_current_asset_disposed = Column(Float(8))
    other_earnings = Column(Float(8))
    rd_expenses = Column(Float(8))
    asset_deal_income = Column(Float(8))
    sust_operate_net_profit = Column(Float(8))
    discon_operate_net_profit = Column(Float(8))
    credit_impairment_loss = Column(Float(8))
    net_open_hedge_income = Column(Float(8))
    interest_cost_fin = Column(Float(8))
    interest_income_fin = Column(Float(8))
    date = Column(Date, primary_key=True)

    def to_dict(self):
        return {c.name: getattr(self, c.name, None) for c in self.__table__.columns}

    @property
    def columns(self):
        return [c.name for c in self.__table__.columns]

    def to_list(self):
        return [getattr(self, c.name, None) for c in self.__table__.columns]


class CN_JQ_STK_INCOME_STATEMENT(Base):
    # 表的名字
    __tablename__ = 'cn_jq_stk_income_statement'

    company_id = Column(Float(8))
    company_name = Column(Text)
    code = Column(Text, primary_key=True)
    a_code = Column(Text)
    b_code = Column(Text)
    h_code = Column(Text)
    pub_date = Column(Date)
    start_date = Column(Date)
    end_date = Column(Date)
    report_date = Column(Date)
    report_type = Column(Float(8))
    source_id = Column(Float(8))
    source = Column(Text)
    total_operating_revenue = Column(Float(8))
    operating_revenue = Column(Float(8))
    total_operating_cost = Column(Float(8))
    operating_cost = Column(Float(8))
    operating_tax_surcharges = Column(Float(8))
    sale_expense = Column(Float(8))
    administration_expense = Column(Float(8))
    exploration_expense = Column(Float(8))
    financial_expense = Column(Float(8))
    asset_impairment_loss = Column(Float(8))
    fair_value_variable_income = Column(Float(8))
    investment_income = Column(Float(8))
    invest_income_associates = Column(Float(8))
    exchange_income = Column(Float(8))
    other_items_influenced_income = Column(Float(8))
    operating_profit = Column(Float(8))
    subsidy_income = Column(Float(8))
    non_operating_revenue = Column(Float(8))
    non_operating_expense = Column(Float(8))
    disposal_loss_non_current_liability = Column(Float(8))
    other_items_influenced_profit = Column(Float(8))
    total_profit = Column(Float(8))
    income_tax = Column(Float(8))
    other_items_influenced_net_profit = Column(Float(8))
    net_profit = Column(Float(8))
    np_parent_company_owners = Column(Float(8))
    minority_profit = Column(Float(8))
    eps = Column(Float(8))
    basic_eps = Column(Float(8))
    diluted_eps = Column(Float(8))
    other_composite_income = Column(Float(8))
    total_composite_income = Column(Float(8))
    ci_parent_company_owners = Column(Float(8))
    ci_minority_owners = Column(Float(8))
    interest_income = Column(Float(8))
    premiums_earned = Column(Float(8))
    commission_income = Column(Float(8))
    interest_expense = Column(Float(8))
    commission_expense = Column(Float(8))
    refunded_premiums = Column(Float(8))
    net_pay_insurance_claims = Column(Float(8))
    withdraw_insurance_contract_reserve = Column(Float(8))
    policy_dividend_payout = Column(Float(8))
    reinsurance_cost = Column(Float(8))
    non_current_asset_disposed = Column(Float(8))
    other_earnings = Column(Float(8))
    rd_expenses = Column(Float(8))
    asset_deal_income = Column(Float(8))
    sust_operate_net_profit = Column(Float(8))
    discon_operate_net_profit = Column(Float(8))
    credit_impairment_loss = Column(Float(8))
    net_open_hedge_income = Column(Float(8))
    interest_cost_fin = Column(Float(8))
    interest_income_fin = Column(Float(8))
    date = Column(Date, primary_key=True)

    def to_dict(self):
        return {c.name: getattr(self, c.name, None) for c in self.__table__.columns}

    @property
    def columns(self):
        return [c.name for c in self.__table__.columns]

    def to_list(self):
        return [getattr(self, c.name, None) for c in self.__table__.columns]


class CN_JQ_STK_CASHFLOW_STATEMENT_PARENT(Base):
    # 表的名字
    __tablename__ = 'cn_jq_stk_cashflow_statement_parent'

    # 表的结构
    company_id = Column(Float(8))
    company_name = Column(Text)
    code = Column(Text)
    a_code = Column(Text)
    b_code = Column(Text)
    h_code = Column(Text)
    pub_date = Column(Date)
    start_date = Column(Date)
    end_date = Column(Date)
    report_date = Column(Date)
    report_type = Column(Float(8))
    source_id = Column(Float(8))
    source = Column(Text)
    goods_sale_and_service_render_cash = Column(Float(8))
    tax_levy_refund = Column(Float(8))
    subtotal_operate_cash_inflow = Column(Float(8))
    goods_and_services_cash_paid = Column(Float(8))
    staff_behalf_paid = Column(Float(8))
    tax_payments = Column(Float(8))
    subtotal_operate_cash_outflow = Column(Float(8))
    net_operate_cash_flow = Column(Float(8))
    invest_withdrawal_cash = Column(Float(8))
    invest_proceeds = Column(Float(8))
    fix_intan_other_asset_dispo_cash = Column(Float(8))
    net_cash_deal_subcompany = Column(Float(8))
    subtotal_invest_cash_inflow = Column(Float(8))
    fix_intan_other_asset_acqui_cash = Column(Float(8))
    invest_cash_paid = Column(Float(8))
    impawned_loan_net_increase = Column(Float(8))
    net_cash_from_sub_company = Column(Float(8))
    subtotal_invest_cash_outflow = Column(Float(8))
    net_invest_cash_flow = Column(Float(8))
    cash_from_invest = Column(Float(8))
    cash_from_borrowing = Column(Float(8))
    cash_from_bonds_issue = Column(Float(8))
    subtotal_finance_cash_inflow = Column(Float(8))
    borrowing_repayment = Column(Float(8))
    dividend_interest_payment = Column(Float(8))
    subtotal_finance_cash_outflow = Column(Float(8))
    net_finance_cash_flow = Column(Float(8))
    exchange_rate_change_effect = Column(Float(8))
    other_reason_effect_cash = Column(Float(8))
    cash_equivalent_increase = Column(Float(8))
    cash_equivalents_at_beginning = Column(Float(8))
    cash_and_equivalents_at_end = Column(Float(8))
    net_profit = Column(Float(8))
    assets_depreciation_reserves = Column(Float(8))
    fixed_assets_depreciation = Column(Float(8))
    intangible_assets_amortization = Column(Float(8))
    defferred_expense_amortization = Column(Float(8))
    fix_intan_other_asset_dispo_loss = Column(Float(8))
    fixed_asset_scrap_loss = Column(Float(8))
    fair_value_change_loss = Column(Float(8))
    financial_cost = Column(Float(8))
    invest_loss = Column(Float(8))
    deffered_tax_asset_decrease = Column(Float(8))
    deffered_tax_liability_increase = Column(Float(8))
    inventory_decrease = Column(Float(8))
    operate_receivables_decrease = Column(Float(8))
    operate_payable_increase = Column(Float(8))
    others = Column(Float(8))
    net_operate_cash_flow_indirect = Column(Float(8))
    debt_to_capital = Column(Float(8))
    cbs_expiring_in_one_year = Column(Float(8))
    financial_lease_fixed_assets = Column(Float(8))
    cash_at_end = Column(Float(8))
    cash_at_beginning = Column(Float(8))
    equivalents_at_end = Column(Float(8))
    equivalents_at_beginning = Column(Float(8))
    other_reason_effect_cash_indirect = Column(Float(8))
    cash_equivalent_increase_indirect = Column(Float(8))
    net_deposit_increase = Column(Float(8))
    net_borrowing_from_central_bank = Column(Float(8))
    net_borrowing_from_finance_co = Column(Float(8))
    net_original_insurance_cash = Column(Float(8))
    net_cash_received_from_reinsurance_business = Column(Float(8))
    net_insurer_deposit_investment = Column(Float(8))
    net_deal_trading_assets = Column(Float(8))
    interest_and_commission_cashin = Column(Float(8))
    net_increase_in_placements = Column(Float(8))
    net_buyback = Column(Float(8))
    net_loan_and_advance_increase = Column(Float(8))
    net_deposit_in_cb_and_ib = Column(Float(8))
    original_compensation_paid = Column(Float(8))
    handling_charges_and_commission = Column(Float(8))
    policy_dividend_cash_paid = Column(Float(8))
    cash_from_mino_s_invest_sub = Column(Float(8))
    proceeds_from_sub_to_mino_s = Column(Float(8))
    investment_property_depreciation = Column(Float(8))
    credit_impairment_loss = Column(Float(8))
    date = Column(Date, primary_key=True)

    def to_dict(self):
        return {c.name: getattr(self, c.name, None) for c in self.__table__.columns}

    @property
    def columns(self):
        return [c.name for c in self.__table__.columns]

    def to_list(self):
        return [getattr(self, c.name, None) for c in self.__table__.columns]


class CN_JQ_STK_CASHFLOW_STATEMENT(Base):
    # 表的名字
    __tablename__ = 'cn_jq_stk_cashflow_statement'

    # 表的结构
    company_id = Column(Float(8))
    company_name = Column(Text)
    code = Column(Text)
    a_code = Column(Text)
    b_code = Column(Text)
    h_code = Column(Text)
    pub_date = Column(Date)
    start_date = Column(Date)
    end_date = Column(Date)
    report_date = Column(Date)
    report_type = Column(Float(8))
    source_id = Column(Float(8))
    source = Column(Text)
    goods_sale_and_service_render_cash = Column(Float(8))
    tax_levy_refund = Column(Float(8))
    subtotal_operate_cash_inflow = Column(Float(8))
    goods_and_services_cash_paid = Column(Float(8))
    staff_behalf_paid = Column(Float(8))
    tax_payments = Column(Float(8))
    subtotal_operate_cash_outflow = Column(Float(8))
    net_operate_cash_flow = Column(Float(8))
    invest_withdrawal_cash = Column(Float(8))
    invest_proceeds = Column(Float(8))
    fix_intan_other_asset_dispo_cash = Column(Float(8))
    net_cash_deal_subcompany = Column(Float(8))
    subtotal_invest_cash_inflow = Column(Float(8))
    fix_intan_other_asset_acqui_cash = Column(Float(8))
    invest_cash_paid = Column(Float(8))
    impawned_loan_net_increase = Column(Float(8))
    net_cash_from_sub_company = Column(Float(8))
    subtotal_invest_cash_outflow = Column(Float(8))
    net_invest_cash_flow = Column(Float(8))
    cash_from_invest = Column(Float(8))
    cash_from_borrowing = Column(Float(8))
    cash_from_bonds_issue = Column(Float(8))
    subtotal_finance_cash_inflow = Column(Float(8))
    borrowing_repayment = Column(Float(8))
    dividend_interest_payment = Column(Float(8))
    subtotal_finance_cash_outflow = Column(Float(8))
    net_finance_cash_flow = Column(Float(8))
    exchange_rate_change_effect = Column(Float(8))
    other_reason_effect_cash = Column(Float(8))
    cash_equivalent_increase = Column(Float(8))
    cash_equivalents_at_beginning = Column(Float(8))
    cash_and_equivalents_at_end = Column(Float(8))
    net_profit = Column(Float(8))
    assets_depreciation_reserves = Column(Float(8))
    fixed_assets_depreciation = Column(Float(8))
    intangible_assets_amortization = Column(Float(8))
    defferred_expense_amortization = Column(Float(8))
    fix_intan_other_asset_dispo_loss = Column(Float(8))
    fixed_asset_scrap_loss = Column(Float(8))
    fair_value_change_loss = Column(Float(8))
    financial_cost = Column(Float(8))
    invest_loss = Column(Float(8))
    deffered_tax_asset_decrease = Column(Float(8))
    deffered_tax_liability_increase = Column(Float(8))
    inventory_decrease = Column(Float(8))
    operate_receivables_decrease = Column(Float(8))
    operate_payable_increase = Column(Float(8))
    others = Column(Float(8))
    net_operate_cash_flow_indirect = Column(Float(8))
    debt_to_capital = Column(Float(8))
    cbs_expiring_in_one_year = Column(Float(8))
    financial_lease_fixed_assets = Column(Float(8))
    cash_at_end = Column(Float(8))
    cash_at_beginning = Column(Float(8))
    equivalents_at_end = Column(Float(8))
    equivalents_at_beginning = Column(Float(8))
    other_reason_effect_cash_indirect = Column(Float(8))
    cash_equivalent_increase_indirect = Column(Float(8))
    net_deposit_increase = Column(Float(8))
    net_borrowing_from_central_bank = Column(Float(8))
    net_borrowing_from_finance_co = Column(Float(8))
    net_original_insurance_cash = Column(Float(8))
    net_cash_received_from_reinsurance_business = Column(Float(8))
    net_insurer_deposit_investment = Column(Float(8))
    net_deal_trading_assets = Column(Float(8))
    interest_and_commission_cashin = Column(Float(8))
    net_increase_in_placements = Column(Float(8))
    net_buyback = Column(Float(8))
    net_loan_and_advance_increase = Column(Float(8))
    net_deposit_in_cb_and_ib = Column(Float(8))
    original_compensation_paid = Column(Float(8))
    handling_charges_and_commission = Column(Float(8))
    policy_dividend_cash_paid = Column(Float(8))
    cash_from_mino_s_invest_sub = Column(Float(8))
    proceeds_from_sub_to_mino_s = Column(Float(8))
    investment_property_depreciation = Column(Float(8))
    credit_impairment_loss = Column(Float(8))
    date = Column(Date, primary_key=True)

    def to_dict(self):
        return {c.name: getattr(self, c.name, None) for c in self.__table__.columns}

    @property
    def columns(self):
        return [c.name for c in self.__table__.columns]

    def to_list(self):
        return [getattr(self, c.name, None) for c in self.__table__.columns]


class CN_JQ_STK_BALANCE_SHEET(Base):
    # 表的名字
    __tablename__ = 'cn_jq_stk_balance_sheet'

    # 表的结构
    company_id = Column(Float(8))
    company_name = Column(Text)
    code = Column(Text, primary_key=True)
    a_code = Column(Text)
    b_code = Column(Text)
    h_code = Column(Text)
    pub_date = Column(Date)
    start_date = Column(Date)
    end_date = Column(Date)
    report_date = Column(Date)
    report_type = Column(Float(8))
    source_id = Column(Float(8))
    source = Column(Text)
    cash_equivalents = Column(Float(8))
    trading_assets = Column(Float(8))
    bill_receivable = Column(Float(8))
    account_receivable = Column(Float(8))
    advance_payment = Column(Float(8))
    other_receivable = Column(Float(8))
    affiliated_company_receivable = Column(Float(8))
    interest_receivable = Column(Float(8))
    dividend_receivable = Column(Float(8))
    inventories = Column(Float(8))
    expendable_biological_asset = Column(Float(8))
    non_current_asset_in_one_year = Column(Float(8))
    total_current_assets = Column(Float(8))
    hold_for_sale_assets = Column(Float(8))
    hold_to_maturity_investments = Column(Float(8))
    longterm_receivable_account = Column(Float(8))
    longterm_equity_invest = Column(Float(8))
    investment_property = Column(Float(8))
    fixed_assets = Column(Float(8))
    constru_in_process = Column(Float(8))
    construction_materials = Column(Float(8))
    fixed_assets_liquidation = Column(Float(8))
    biological_assets = Column(Float(8))
    oil_gas_assets = Column(Float(8))
    intangible_assets = Column(Float(8))
    development_expenditure = Column(Float(8))
    good_will = Column(Float(8))
    long_deferred_expense = Column(Float(8))
    deferred_tax_assets = Column(Float(8))
    total_non_current_assets = Column(Float(8))
    total_assets = Column(Float(8))
    shortterm_loan = Column(Float(8))
    trading_liability = Column(Float(8))
    notes_payable = Column(Float(8))
    accounts_payable = Column(Float(8))
    advance_peceipts = Column(Float(8))
    salaries_payable = Column(Float(8))
    taxs_payable = Column(Float(8))
    interest_payable = Column(Float(8))
    dividend_payable = Column(Float(8))
    other_payable = Column(Float(8))
    affiliated_company_payable = Column(Float(8))
    non_current_liability_in_one_year = Column(Float(8))
    total_current_liability = Column(Float(8))
    longterm_loan = Column(Float(8))
    bonds_payable = Column(Float(8))
    longterm_account_payable = Column(Float(8))
    specific_account_payable = Column(Float(8))
    estimate_liability = Column(Float(8))
    deferred_tax_liability = Column(Float(8))
    total_non_current_liability = Column(Float(8))
    total_liability = Column(Float(8))
    paidin_capital = Column(Float(8))
    capital_reserve_fund = Column(Float(8))
    specific_reserves = Column(Float(8))
    surplus_reserve_fund = Column(Float(8))
    treasury_stock = Column(Float(8))
    retained_profit = Column(Float(8))
    equities_parent_company_owners = Column(Float(8))
    minority_interests = Column(Float(8))
    foreign_currency_report_conv_diff = Column(Float(8))
    irregular_item_adjustment = Column(Float(8))
    total_owner_equities = Column(Float(8))
    total_sheet_owner_equities = Column(Float(8))
    other_comprehensive_income = Column(Float(8))
    deferred_earning = Column(Float(8))
    settlement_provi = Column(Float(8))
    lend_capital = Column(Float(8))
    loan_and_advance_current_assets = Column(Float(8))
    derivative_financial_asset = Column(Float(8))
    insurance_receivables = Column(Float(8))
    reinsurance_receivables = Column(Float(8))
    reinsurance_contract_reserves_receivable = Column(Float(8))
    bought_sellback_assets = Column(Float(8))
    hold_sale_asset = Column(Float(8))
    loan_and_advance_noncurrent_assets = Column(Float(8))
    borrowing_from_centralbank = Column(Float(8))
    deposit_in_interbank = Column(Float(8))
    borrowing_capital = Column(Float(8))
    derivative_financial_liability = Column(Float(8))
    sold_buyback_secu_proceeds = Column(Float(8))
    commission_payable = Column(Float(8))
    reinsurance_payables = Column(Float(8))
    insurance_contract_reserves = Column(Float(8))
    proxy_secu_proceeds = Column(Float(8))
    receivings_from_vicariously_sold_securities = Column(Float(8))
    hold_sale_liability = Column(Float(8))
    estimate_liability_current = Column(Float(8))
    deferred_earning_current = Column(Float(8))
    preferred_shares_noncurrent = Column(Float(8))
    pepertual_liability_noncurrent = Column(Float(8))
    longterm_salaries_payable = Column(Float(8))
    other_equity_tools = Column(Float(8))
    preferred_shares_equity = Column(Float(8))
    pepertual_liability_equity = Column(Float(8))
    bill_and_account_receivable = Column(Float(8))
    bill_and_account_payable = Column(Float(8))
    receivable_fin = Column(Float(8))
    usufruct_assets = Column(Float(8))
    other_current_assets = Column(Float(8))
    other_non_current_assets = Column(Float(8))
    other_current_liability = Column(Float(8))
    other_non_current_liability = Column(Float(8))
    ordinary_risk_reserve_fund = Column(Float(8))
    contract_assets = Column(Float(8))
    bond_invest = Column(Float(8))
    other_bond_invest = Column(Float(8))
    other_equity_tools_invest = Column(Float(8))
    other_non_current_financial_assets = Column(Float(8))
    contract_liability = Column(Float(8))
    date = Column(Date, primary_key=True)

    def to_dict(self):
        return {c.name: getattr(self, c.name, None) for c in self.__table__.columns}

    @property
    def columns(self):
        return [c.name for c in self.__table__.columns]

    def to_list(self):
        return [getattr(self, c.name, None) for c in self.__table__.columns]


class CN_JQ_STK_BALANCE_SHEET_PARENT(Base):
    # 表的名字
    __tablename__ = 'cn_jq_stk_balance_sheet_parent'

    # 表的结构
    company_id = Column(Float(8))
    company_name = Column(Text)
    code = Column(Text, primary_key=True)
    a_code = Column(Text)
    b_code = Column(Text)
    h_code = Column(Text)
    pub_date = Column(Date)
    start_date = Column(Date)
    end_date = Column(Date)
    report_date = Column(Date)
    report_type = Column(Float(8))
    source_id = Column(Float(8))
    source = Column(Text)
    cash_equivalents = Column(Float(8))
    trading_assets = Column(Float(8))
    bill_receivable = Column(Float(8))
    account_receivable = Column(Float(8))
    advance_payment = Column(Float(8))
    other_receivable = Column(Float(8))
    affiliated_company_receivable = Column(Float(8))
    interest_receivable = Column(Float(8))
    dividend_receivable = Column(Float(8))
    inventories = Column(Float(8))
    expendable_biological_asset = Column(Float(8))
    non_current_asset_in_one_year = Column(Float(8))
    total_current_assets = Column(Float(8))
    hold_for_sale_assets = Column(Float(8))
    hold_to_maturity_investments = Column(Float(8))
    longterm_receivable_account = Column(Float(8))
    longterm_equity_invest = Column(Float(8))
    investment_property = Column(Float(8))
    fixed_assets = Column(Float(8))
    constru_in_process = Column(Float(8))
    construction_materials = Column(Float(8))
    fixed_assets_liquidation = Column(Float(8))
    biological_assets = Column(Float(8))
    oil_gas_assets = Column(Float(8))
    intangible_assets = Column(Float(8))
    development_expenditure = Column(Float(8))
    good_will = Column(Float(8))
    long_deferred_expense = Column(Float(8))
    deferred_tax_assets = Column(Float(8))
    total_non_current_assets = Column(Float(8))
    total_assets = Column(Float(8))
    shortterm_loan = Column(Float(8))
    trading_liability = Column(Float(8))
    notes_payable = Column(Float(8))
    accounts_payable = Column(Float(8))
    advance_peceipts = Column(Float(8))
    salaries_payable = Column(Float(8))
    taxs_payable = Column(Float(8))
    interest_payable = Column(Float(8))
    dividend_payable = Column(Float(8))
    other_payable = Column(Float(8))
    affiliated_company_payable = Column(Float(8))
    non_current_liability_in_one_year = Column(Float(8))
    total_current_liability = Column(Float(8))
    longterm_loan = Column(Float(8))
    bonds_payable = Column(Float(8))
    longterm_account_payable = Column(Float(8))
    specific_account_payable = Column(Float(8))
    estimate_liability = Column(Float(8))
    deferred_tax_liability = Column(Float(8))
    total_non_current_liability = Column(Float(8))
    total_liability = Column(Float(8))
    paidin_capital = Column(Float(8))
    capital_reserve_fund = Column(Float(8))
    specific_reserves = Column(Float(8))
    surplus_reserve_fund = Column(Float(8))
    treasury_stock = Column(Float(8))
    retained_profit = Column(Float(8))
    equities_parent_company_owners = Column(Float(8))
    minority_interests = Column(Float(8))
    foreign_currency_report_conv_diff = Column(Float(8))
    irregular_item_adjustment = Column(Float(8))
    total_owner_equities = Column(Float(8))
    total_sheet_owner_equities = Column(Float(8))
    other_comprehensive_income = Column(Float(8))
    deferred_earning = Column(Float(8))
    settlement_provi = Column(Float(8))
    lend_capital = Column(Float(8))
    loan_and_advance_current_assets = Column(Float(8))
    derivative_financial_asset = Column(Float(8))
    insurance_receivables = Column(Float(8))
    reinsurance_receivables = Column(Float(8))
    reinsurance_contract_reserves_receivable = Column(Float(8))
    bought_sellback_assets = Column(Float(8))
    hold_sale_asset = Column(Float(8))
    loan_and_advance_noncurrent_assets = Column(Float(8))
    borrowing_from_centralbank = Column(Float(8))
    deposit_in_interbank = Column(Float(8))
    borrowing_capital = Column(Float(8))
    derivative_financial_liability = Column(Float(8))
    sold_buyback_secu_proceeds = Column(Float(8))
    commission_payable = Column(Float(8))
    reinsurance_payables = Column(Float(8))
    insurance_contract_reserves = Column(Float(8))
    proxy_secu_proceeds = Column(Float(8))
    receivings_from_vicariously_sold_securities = Column(Float(8))
    hold_sale_liability = Column(Float(8))
    estimate_liability_current = Column(Float(8))
    deferred_earning_current = Column(Float(8))
    preferred_shares_noncurrent = Column(Float(8))
    pepertual_liability_noncurrent = Column(Float(8))
    longterm_salaries_payable = Column(Float(8))
    other_equity_tools = Column(Float(8))
    preferred_shares_equity = Column(Float(8))
    pepertual_liability_equity = Column(Float(8))
    bill_and_account_receivable = Column(Float(8))
    bill_and_account_payable = Column(Float(8))
    receivable_fin = Column(Float(8))
    usufruct_assets = Column(Float(8))
    other_current_assets = Column(Float(8))
    other_non_current_assets = Column(Float(8))
    other_current_liability = Column(Float(8))
    other_non_current_liability = Column(Float(8))
    ordinary_risk_reserve_fund = Column(Float(8))
    contract_assets = Column(Float(8))
    bond_invest = Column(Float(8))
    other_bond_invest = Column(Float(8))
    other_equity_tools_invest = Column(Float(8))
    other_non_current_financial_assets = Column(Float(8))
    contract_liability = Column(Float(8))
    date = Column(Date, primary_key=True)

    def to_dict(self):
        return {c.name: getattr(self, c.name, None) for c in self.__table__.columns}

    @property
    def columns(self):
        return [c.name for c in self.__table__.columns]

    def to_list(self):
        return [getattr(self, c.name, None) for c in self.__table__.columns]


class CN_JQ_STK_VALUATION(Base):
    # 表的名字
    __tablename__ = 'cn_jq_stk_valuation'

    # 表的结构
    date = Column(Date, primary_key=True)
    code = Column(Text, primary_key=True)
    pe_ratio = Column(Float(8))
    turnover_ratio = Column(Float(8))
    pb_ratio = Column(Float(8))
    ps_ratio = Column(Float(8))
    pcf_ratio = Column(Float(8))
    capitalization = Column(Float(8))
    market_cap = Column(Float(8))
    circulating_cap = Column(Float(8))
    circulating_market_cap = Column(Float(8))
    pe_ratio_lyr = Column(Float(8))

    def to_dict(self):
        return {c.name: getattr(self, c.name, None) for c in self.__table__.columns}

    @property
    def columns(self):
        return [c.name for c in self.__table__.columns]

    def to_list(self):
        return [getattr(self, c.name, None) for c in self.__table__.columns]
